summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KURLComboBox.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KURLComboBox.java')
-rw-r--r--kdejava/koala/org/kde/koala/KURLComboBox.java32
1 files changed, 16 insertions, 16 deletions
diff --git a/kdejava/koala/org/kde/koala/KURLComboBox.java b/kdejava/koala/org/kde/koala/KURLComboBox.java
index 3154f4e1..720ba032 100644
--- a/kdejava/koala/org/kde/koala/KURLComboBox.java
+++ b/kdejava/koala/org/kde/koala/KURLComboBox.java
@@ -2,11 +2,11 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QMetaObject;
+import org.kde.qt.TQMetaObject;
import org.kde.qt.QtSupport;
-import org.kde.qt.QPixmap;
+import org.kde.qt.TQPixmap;
import java.util.ArrayList;
-import org.kde.qt.QWidget;
+import org.kde.qt.TQWidget;
/**
@@ -47,7 +47,7 @@ public class KURLComboBox extends KComboBox {
public static final int RemoveTop = 0;
public static final int RemoveBottom = 1;
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
/**
Constructs a KURLComboBox.
@@ -74,31 +74,31 @@ public class KURLComboBox extends KComboBox {
@param name The name of this widget.
@short Constructs a KURLComboBox.
*/
- public KURLComboBox(int mode, QWidget parent, String name) {
+ public KURLComboBox(int mode, TQWidget parent, String name) {
super((Class) null);
newKURLComboBox(mode,parent,name);
}
- private native void newKURLComboBox(int mode, QWidget parent, String name);
- public KURLComboBox(int mode, QWidget parent) {
+ private native void newKURLComboBox(int mode, TQWidget parent, String name);
+ public KURLComboBox(int mode, TQWidget parent) {
super((Class) null);
newKURLComboBox(mode,parent);
}
- private native void newKURLComboBox(int mode, QWidget parent);
+ private native void newKURLComboBox(int mode, TQWidget parent);
public KURLComboBox(int mode) {
super((Class) null);
newKURLComboBox(mode);
}
private native void newKURLComboBox(int mode);
- public KURLComboBox(int mode, boolean rw, QWidget parent, String name) {
+ public KURLComboBox(int mode, boolean rw, TQWidget parent, String name) {
super((Class) null);
newKURLComboBox(mode,rw,parent,name);
}
- private native void newKURLComboBox(int mode, boolean rw, QWidget parent, String name);
- public KURLComboBox(int mode, boolean rw, QWidget parent) {
+ private native void newKURLComboBox(int mode, boolean rw, TQWidget parent, String name);
+ public KURLComboBox(int mode, boolean rw, TQWidget parent) {
super((Class) null);
newKURLComboBox(mode,rw,parent);
}
- private native void newKURLComboBox(int mode, boolean rw, QWidget parent);
+ private native void newKURLComboBox(int mode, boolean rw, TQWidget parent);
public KURLComboBox(int mode, boolean rw) {
super((Class) null);
newKURLComboBox(mode,rw);
@@ -179,8 +179,8 @@ public class KURLComboBox extends KComboBox {
Default URLs will be inserted into the combobox by setDefaults()
@short Adds a url that will always be shown in the combobox, it can't be "rotated away".
*/
- public native void addDefaultURL(KURL url, QPixmap pix, String text);
- public native void addDefaultURL(KURL url, QPixmap pix);
+ public native void addDefaultURL(KURL url, TQPixmap pix, String text);
+ public native void addDefaultURL(KURL url, TQPixmap pix);
/**
Clears all items and inserts the default urls into the combo. Will be
called implicitly upon the first call to setURLs() or setURL()
@@ -202,14 +202,14 @@ public class KURLComboBox extends KComboBox {
In directory mode, a folder icon is always returned.
@short Uses KMimeType.pixmapForURL() to return a proper pixmap for <code>url.</code>
*/
- protected native QPixmap getPixmap(KURL url);
+ protected native TQPixmap getPixmap(KURL url);
/**
Updates <code>item</code> with <code>pixmap</code> and sets the url instead of the text
of the KURLComboItem.
Also works around a Qt bug.
@short Updates <code>item</code> with <code>pixmap</code> and sets the url instead of the text of the KURLComboItem.
*/
// void updateItem(const KURLComboBox::KURLComboItem* arg1,int arg2,const QPixmap& arg3); >>>> NOT CONVERTED
protected native void slotActivated(int arg1);
/** Deletes the wrapped C++ instance */
protected native void finalize() throws InternalError;
@@ -202,14 +202,14 @@ public class KURLComboBox extends KComboBox {
*/
- // void updateItem(const KURLComboBox::KURLComboItem* arg1,int arg2,const QPixmap& arg3); >>>> NOT CONVERTED
+ // void updateItem(const KURLComboBox::KURLComboItem* arg1,int arg2,const TQPixmap& arg3); >>>> NOT CONVERTED
protected native void slotActivated(int arg1);
/** Deletes the wrapped C++ instance */